Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TLogProof ¶
type TLogProof struct {
// Index is the index of an entry in the log
Index uint64
// Hashes is the Merkle inclusion proof as described in https://www.rfc-editor.org/rfc/rfc6962.html#section-2.1.1
Hashes [][sha256.Size]byte
// Checkpoint is the signed note as described in https://c2sp.org/tlog-checkpoint
Checkpoint []byte
// ExtraData contains optional application-specific data
ExtraData []byte
}
TLogProof represents a transparency log proof as described in https://c2sp.org/tlog-proof
Click to show internal directories.
Click to hide internal directories.